@@ -221,7 +221,7 @@ class GSOM:
         rightx, righty = x + 1, y
         topx, topy = x, y + 1
         bottomx, bottomy = x, y - 1
-        self.node_errors[self.map[(x, y)]] = self.groth_threshold   #TODO check this value if different in Rashmika's
+        self.node_errors[self.map[(x, y)]] = self.groth_threshold/2   #TODO check this value if different in Rashmika's
                                                                     # version and paper version (paper t/2 Rashmika t)
         self.node_errors[self.map[(leftx, lefty)]] *= (1 + self.FD)
         self.node_errors[self.map[(rightx, righty)]] *= (1 + self.FD)
@@ -245,7 +245,7 @@ class GSOM:
             self.grow_node(x, y, rightx, righty, 1)
             self.grow_node(x, y, topx, topy, 2)
             self.grow_node(x, y, bottomx, bottomy, 3)
-        # self.node_errors[rmu_index] = 0 #TODO check the need of setting the error to zero after weight adaptation
+        self.node_errors[rmu_index] = self.groth_threshold/2 #TODO check the need of setting the error to zero after weight adaptation
 
     def winner_identification_and_neighbourhood_update(self, data_index, data, radius, learning_rate):
         out = scipy.spatial.distance.cdist(self.node_list[:self.node_count], data[data_index, :].reshape(1, self.dimentions), self.distance)
@@ -316,6 +316,9 @@ class GSOM:
                 current_learning_rate = self._get_learning_rate(current_learning_rate)
 
             self.smooth(data, radius_exp, current_learning_rate)
+        # Identify winners
+        out = scipy.spatial.distance.cdist(self.node_list[:self.node_count], data, self.distance)
+        return out.argmin(axis=0)
 
     def predict(self, data, index_col, label_col=None):
         """
@@ -344,8 +347,10 @@ class GSOM:
 
         grp_output =data_out.groupby("output")
         dn = grp_output[index_col].apply(list).reset_index()
+        dn = dn.set_index("output")
         if label_col:
             dn[label_col] = grp_output[label_col].apply(list)
+        dn = dn.reset_index()
         dn["hit_count"] = dn[index_col].apply(lambda x: len(x))
         dn["x"] = dn["output"].apply(lambda x: self.node_coordinate[x, 0])
         dn["y"] = dn["output"].apply(lambda x: self.node_coordinate[x, 1])
@@ -365,7 +370,7 @@ if __name__ == '__main__':
     data_training = df.iloc[:, 1:17]
     gsom = GSOM(.83, 16, max_radius=4)
     gsom.fit(data_training.to_numpy(), 100, 50)
-    gsom.predict(df,"Name","label")
-    gsom.output.to_csv("output.csv")
+    output = gsom.predict(df,"Name","label")
+    output.to_csv("output.csv", index=False)
 
     print("complete")
